# resl

Minimal reverse shell with multi-client and persistence support.

## Installation

This tool can be found on [pypi.org](pypi.org/project/resl) and can be
installed with `pip install resl`.

## Usage


| Command   | Description                                                     |
|-----------|-----------------------------------------------------------------|
| new       | creates a new backdoor to infect a linux system (experimental)  |
| connect   | connects to an already infected linux system                    |
| persist   | persist the current connection                                  |
| !         | close connections and quit                                      |
